from langchain.prompts import (
    ChatPromptTemplate,
    HumanMessagePromptTemplate,
    MessagesPlaceholder,
    SystemMessagePromptTemplate,
)

# System templates
sigma_system_template = """You are a threat detection engineering assistant bot specializing in Sigma Rules.
You have four tools at your disposal:
1. translate_sigma_rule: converts or translates a Sigma Rule into a query for a specific backend/product. 
2. find_sigma_rule: Searches for a Sigma Rule in the vector database based on the users question. 
3. create_sigma_rule_vectorstore: Creates new Sigma Rule from the users input, as well as rules in a sigma rule vectorstore to use as context based on the users question. If the user's question already contains a query, use 'query_to_sigma_rule' instead. 
4. query_to_sigma_rule: Converts/translates a product/SIEM/backend query or search from the query language into a YAML Sigma Rule."""

snort_system_template = """You are a threat detection engineering assistant bot specializing in Snort IDS rules.
You have two tools at your disposal:
1. analyze_pcap: Analyzes a PCAP file to identify network patterns, protocols, and potential malicious behaviors.
2. create_snort_rule: Creates Snort rules based on the PCAP analysis results to detect similar malicious behaviors."""

yara_system_template = """You are a threat detection engineering assistant bot specializing in YARA rules.
You have four tools at your disposal:
1. scan_file: Scans files with existing YARA rules to identify matches
2. analyze_file: Analyzes files to identify unique patterns, strings, and characteristics
3. create_yara_rule: Creates YARA rules based on either:
   - File analysis results from analyze_file
   - A description of what you want to detect
4. find_yara_rule: Searches for existing YARA rules in the vector database.

If the response contains sections like == Analysis Summary ===, === Detection Strategy ===, and === YARA Rule ===, ensure that all sections are present and detailed.
"""

# Create prompts
SIGMA_AGENT_PROMPT = ChatPromptTemplate.from_messages(
    [
        SystemMessagePromptTemplate.from_template(sigma_system_template),
        MessagesPlaceholder(variable_name="chat_history", optional=True),
        HumanMessagePromptTemplate.from_template("{input}"),
        MessagesPlaceholder(variable_name="agent_scratchpad"),
    ]
)

SNORT_AGENT_PROMPT = ChatPromptTemplate.from_messages(
    [
        SystemMessagePromptTemplate.from_template(snort_system_template),
        MessagesPlaceholder(variable_name="chat_history", optional=True),
        HumanMessagePromptTemplate.from_template("{input}"),
        MessagesPlaceholder(variable_name="agent_scratchpad"),
    ]
)

YARA_AGENT_PROMPT = ChatPromptTemplate.from_messages(
    [
        SystemMessagePromptTemplate.from_template(yara_system_template),
        MessagesPlaceholder(variable_name="chat_history", optional=True),
        HumanMessagePromptTemplate.from_template("{input}"),
        MessagesPlaceholder(variable_name="agent_scratchpad"),
    ]
)



from detectiq.core.llm.tools.sigma import CreateSigmaRuleTool, FindSigmaRuleTool
from detectiq.core.llm.tools.snort import (
    AnalyzePcapTool,
    CreateSnortRuleTool,
    FindSnortRuleTool,
)
from detectiq.core.llm.tools.yara import (
    AnalyzeFileTool,
    CreateYaraRuleTool,
    FindYaraRuleTool,
)

__all__ = [
    # Sigma tools
    "CreateSigmaRuleTool",
    "FindSigmaRuleTool",
    # Snort tools
    "CreateSnortRuleTool",
    "FindSnortRuleTool",
    "AnalyzePcapTool",
    # YARA tools
    "CreateYaraRuleTool",
    "FindYaraRuleTool",
    "AnalyzeFileTool",
]
